@@ -5,7 +5,7 @@
 # License : Copyright (c) 2006, 2007, 2008, 2009, 2010 Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
-# Contact : Erick Antezana <erick.antezana@gmail.com>
+# Contact : Erick Antezana <erick.antezana -@- gmail.com>
 #
 package OBO::Parser::OWLParser;
 
@@ -32,7 +32,7 @@ http://www.bioontology.org/wiki/index.php/OboInOwl:Main_Page
 
 =head1 AUTHOR
 
-Erick Antezana, E<lt>erick.antezana@gmail.comE<gt>
+Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
