@@ -28,13 +28,15 @@ foreach my $r (@my_rels) {
 
 exit 0;
 
+__END__
+
 =head1 NAME
 
-get_terms.pl - Find all the relationships in a given ontology.
+get_relationship_types.pl - Find all the relationship types in a given ontology.
 
 =head1 DESCRIPTION
 
-This script retrieves all the names of the relationships in a given ontology.
+This script retrieves all the relationship types in a given ontology.
 
 =head1 AUTHOR
 
